colorScheme property

ColorScheme? colorScheme
final

Optional color scheme to apply on top of the active theme.

When provided, overrides the color scheme from the active Themed theme while keeping all other theme properties intact. Useful for customizing brand colors without creating a full custom theme via Themed.createTheme.

Example:

ThemedApp.router(
  title: 'My App',
  routerConfig: myRouter,
  colorScheme: ColorScheme.dark(
    primary: Color(0xFF00E676),
    secondary: Color(0xFF69F0AE),
  ),
)

Implementation

final ColorScheme? colorScheme;